import { CoinspotApiBase } from './coinspotApiBase';
export class AuthenticatedCoinspotReadOnlyApi extends CoinspotApiBase {
    async getBalances() {
        return this.request('/my/balances', {}, true);
    }
    // Helper method to get balances in a more usable format
    async getFormattedBalances() {
        const response = await this.getBalances();
        return response.balances.reduce((acc, entry) => {
            const [coin, balance] = Object.entries(entry)[0];
            acc[coin] = balance;
            return acc;
        }, {});
    }
    // Add more methods for other authenticated endpoints
    async withdrawCoin(cointype, amount, address, options) {
        return this.request('/my/coin/withdraw/send', {
            cointype,
            amount,
            address,
            ...options
        });
    }
    async getReadOnlyStatus() {
        return this.request('/status', {}, true);
    }
    async getOpenMarketOrders(cointype, markettype) {
        return this.request('/orders/market/open', { cointype, markettype }, true);
    }
    async getMyOpenMarketOrders(cointype, markettype) {
        return this.request('/my/orders/market/open', { cointype, markettype }, true);
    }
    async getCompletedMarketOrders(options) {
        return this.request('/orders/market/completed', options, true);
    }
    async getSingleCoinBalance(cointype, available) {
        return this.request(`/my/balance/${cointype}?available=${available}`, {}, true);
    }
    async getMyOpenLimitOrders(cointype) {
        return this.request('/my/orders/limit/open', { cointype }, true);
    }
    async getMyOrderHistory(options) {
        return this.request('/my/orders/completed', options, true);
    }
    async getMyMarketOrderHistory(options) {
        return this.request('/my/orders/market/completed', options, true);
    }
    async getMySendReceiveHistory(startdate, enddate) {
        return this.request('/my/sendreceive', { startdate, enddate }, true);
    }
    async getMyDepositHistory(startdate, enddate) {
        return this.request('/my/deposits', { startdate, enddate }, true);
    }
    async getMyWithdrawalHistory(startdate, enddate) {
        return this.request('/my/withdrawals', { startdate, enddate }, true);
    }
    async getMyAffiliatePayments() {
        return this.request('/my/affiliatepayments', {}, true);
    }
    async getMyReferralPayments() {
        return this.request('/my/referralpayments', {}, true);
    }
}
//# sourceMappingURL=authenticatedReadOnlyApi.js.map